@@ -11,9 +11,9 @@
 
 // Start of defines instantiated by CMake.
 // clang-format off
-#define MPPP_VERSION_STRING "0.13"
+#define MPPP_VERSION_STRING "0.14"
 #define MPPP_VERSION_MAJOR 0
-#define MPPP_VERSION_MINOR 13
+#define MPPP_VERSION_MINOR 14
 #define MPPP_WITH_MPFR
 
 // clang-format on
@@ -65,7 +65,7 @@
 // - at least some early versions of the Intel compiler have a buggy implementation. This
 //   came out from testing, but it might be fixed now.
 
-#if (defined(__apple_build_version__) && __clang_major__ < 8) || defined(__MINGW32__) || defined(__INTEL_COMPILER)
+#if (defined(__APPLE__) && __clang_major__ < 8) || defined(__MINGW32__) || defined(__INTEL_COMPILER)
 
 #define MPPP_MAYBE_TLS
 
