@@ -1,4 +1,4 @@
-// Copyright 2016-2018 Francesco Biscani (bluescarni@gmail.com)
+// Copyright 2016-2019 Francesco Biscani (bluescarni@gmail.com)
 //
 // This file is part of the mp++ library.
 //
@@ -21,6 +21,6 @@ template <std::size_t>
 class rational;
 
 class real;
-}
+} // namespace mppp
 
 #endif
