@@ -14,8 +14,6 @@
 #include <type_traits>
 #include <utility>
 
-#include <mp++/detail/type_traits.hpp>
-
 #if __GNU_MP_VERSION < 5
 
 #error Minimum supported GMP version is 5.
@@ -25,11 +23,11 @@
 namespace mppp
 {
 
-inline namespace detail
+namespace detail
 {
 
 // mpz_t is an array of some struct.
-using mpz_struct_t = remove_extent_t<::mpz_t>;
+using mpz_struct_t = std::remove_extent<::mpz_t>::type;
 // Integral types used for allocation size and number of limbs.
 using mpz_alloc_t = decltype(std::declval<mpz_struct_t>()._mp_alloc);
 using mpz_size_t = decltype(std::declval<mpz_struct_t>()._mp_size);
@@ -57,7 +55,7 @@ struct mpz_raii {
 };
 
 // mpq_t is an array of some struct.
-using mpq_struct_t = remove_extent_t<::mpq_t>;
+using mpq_struct_t = std::remove_extent<::mpq_t>::type;
 
 // Simple RAII holder for GMP rationals.
 struct mpq_raii {
@@ -77,7 +75,7 @@ struct mpq_raii {
 };
 
 // mpf_t is an array of some struct.
-using mpf_struct_t = remove_extent_t<::mpf_t>;
+using mpf_struct_t = std::remove_extent<::mpf_t>::type;
 
 // Simple RAII holder for GMP floats.
 struct mpf_raii {
