@@ -9,17 +9,12 @@
 #ifndef MPPP_DETAIL_MPFR_HPP
 #define MPPP_DETAIL_MPFR_HPP
 
-#include <cstdlib>
-#include <iostream>
 #include <limits>
-#include <memory>
 #include <mpfr.h>
 #include <type_traits>
 
-#include <mp++/config.hpp>
 #include <mp++/detail/gmp.hpp>
 #include <mp++/detail/type_traits.hpp>
-#include <mp++/detail/utils.hpp>
 
 #if MPFR_VERSION_MAJOR < 3
 
@@ -80,7 +75,7 @@ constexpr ::mpfr_prec_t real_prec_max()
 // The MPFR structure underlying mpfr_t.
 using mpfr_struct_t = std::remove_extent<::mpfr_t>::type;
 
-inline namespace detail
+namespace detail
 {
 
 // Paranoia checks.
@@ -115,9 +110,6 @@ struct mpfr_raii {
     mpfr_struct_t m_mpfr;
 };
 
-// Smart pointer to handle the string output from mpfr.
-using smart_mpfr_str = std::unique_ptr<char, void (*)(char *)>;
-
 // A couple of sanity checks when constructing temporary mpfrs/mpfs from long double.
 static_assert(std::numeric_limits<long double>::max_digits10 < nl_max<int>() / 4, "Overflow error.");
 static_assert(std::numeric_limits<long double>::max_digits10 * 4 < nl_max<::mpfr_prec_t>(), "Overflow error.");
@@ -125,63 +117,6 @@ static_assert(std::numeric_limits<long double>::max_digits10 * 4 < nl_max<::mp_b
 static_assert(real_prec_check(static_cast<::mpfr_prec_t>(std::numeric_limits<long double>::max_digits10 * 4)),
               "The precision required to represent long double is outside the MPFR min/max precision bounds.");
 
-// Machinery to call automatically mpfr_free_cache() at program shutdown,
-// if this header is included.
-
-extern "C" {
-
-// NOTE: the cleanup function should have C linkage, as it will be passed to atexit()
-// which is a function from the C standard library.
-void mpfr_cleanup_function();
-}
-
-// The actual implementation.
-inline void mpfr_cleanup_function()
-{
-#if !defined(NDEBUG)
-    // NOTE: functions registered with atexit() may be called concurrently.
-    // Access to cout from concurrent threads is safe as long as the
-    // cout object is synchronized to the underlying C stream:
-    // https://stackoverflow.com/questions/6374264/is-cout-synchronized-thread-safe
-    // http://en.cppreference.com/w/cpp/io/ios_base/sync_with_stdio
-    // By default, this is the case, but in theory someone might have changed
-    // the sync setting on cout by the time we execute the following line.
-    // However, we print only in debug mode, so it should not be too much of a problem
-    // in practice.
-    std::cout << "Cleaning up MPFR caches." << std::endl;
-#endif
-    ::mpfr_free_cache();
-}
-
-struct mpfr_cleanup {
-    mpfr_cleanup()
-    {
-        std::atexit(mpfr_cleanup_function);
-    }
-};
-
-#if MPPP_CPLUSPLUS < 201703L
-
-// Inline variable emulation machinery for pre-C++17.
-template <typename = void>
-struct mpfr_cleanup_holder {
-    static const mpfr_cleanup s_cleanup;
-};
-
-template <typename T>
-const mpfr_cleanup mpfr_cleanup_holder<T>::s_cleanup;
-
-inline void inst_mpfr_cleanup()
-{
-    auto ptr = &mpfr_cleanup_holder<>::s_cleanup;
-    ignore(ptr);
-}
-
-#else
-
-inline const mpfr_cleanup mpfr_cleanup_register;
-
-#endif
 } // namespace detail
 } // namespace mppp
 
